Class: Majesticseo::Row

Inherits:
Structure
  • Object
show all
Defined in:
lib/majesticseo.rb

Overview

Structure respresenting one data row. Can be accessed either as a Ruby object, or as an array. Object methods are underscored versions of the actual array element keys. =Example maj = Majesticseo::Client.new(:app_api_key => "APPKEYHASH") maj.get_subscription_info puts maj.data_tables.first.rows.first => 99992 puts maj.data_tables.first.rows.first.index_item_info_res_units => 99992

Method Summary

Methods inherited from Structure

#[]