Class: Majesticseo::GlobalVars
- Defined in:
- lib/majesticseo.rb
Overview
Structure respresenting a response global vers element. Can be accessed either as a Ruby object, or as an array. Object methods are underscored versions of the actual array element keys. =Example maj = Majesticseo::Client.new(:app_api_key => "APPKEYHASH") maj.get_subscription_info puts maj.global_vars => 120 puts maj.global_vars.max_bulk_backlinks_check => 120